#
# Author:: Daniel DeLeo (<dan@chef.io>)
# Copyright:: Copyright 2010-2016, Chef Software Inc.
# License:: Apache License, Version 2.0
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

require "chef/knife"
class Chef::Knife::RecipeList < Chef::Knife

  banner "knife recipe list [PATTERN]"

  def run
    recipes = rest.get("cookbooks/_recipes")
    if pattern = @name_args.first
      recipes = recipes.grep(Regexp.new(pattern))
    end
    output(recipes)
  end

end
